@@ -1,16 +1,12 @@
 from __future__ import annotations
 
 from enum import Enum
-from typing import Any
-
-from typing_extensions import Self
+from typing import Any, Self
 
 from ..exceptions import CustomValueError, NotFoundEnumValue
-from ..types import FuncExceptT
+from ..types import FuncExcept
 
-__all__ = [
-    'CustomEnum', 'CustomIntEnum', 'CustomStrEnum'
-]
+__all__ = ["CustomEnum", "CustomIntEnum", "CustomStrEnum"]
 
 
 class CustomEnum(Enum):
@@ -21,7 +17,7 @@ class CustomEnum(Enum):
         return cls.from_param(value)
 
     @classmethod
-    def from_param(cls, value: Any, func_except: FuncExceptT | None = None) -> Self | None:
+    def from_param(cls, value: Any, func_except: FuncExcept | None = None) -> Self | None:
         """
         Return the enum value from a parameter.
 
@@ -43,7 +39,7 @@ class CustomEnum(Enum):
             return value
 
         if value is cls:
-            raise CustomValueError('You must select a member, not pass the enum!', func_except)
+            raise CustomValueError("You must select a member, not pass the enum!", func_except)
 
         try:
             return cls(value)
@@ -57,20 +53,19 @@ class CustomEnum(Enum):
 
         raise NotFoundEnumValue(
             'The given value for "{var_name}" argument must be a valid {enum_name}, not "{value}"!\n'
-            'Valid values are: [{readable_enum}].', func_name,
-            var_name=var_name, enum_name=cls, value=value,
-            readable_enum=iter([f'{x.name} ({x.value})' for x in cls]),
-            reason=value
+            "Valid values are: [{readable_enum}].",
+            func_name,
+            var_name=var_name,
+            enum_name=cls,
+            value=value,
+            readable_enum=iter([f"{x.name} ({x.value})" for x in cls]),
+            reason=value,
         )
 
 
 class CustomIntEnum(int, CustomEnum):
     """Base class for custom int enums."""
 
-    value: int
-
 
 class CustomStrEnum(str, CustomEnum):
     """Base class for custom str enums."""
-
-    value: str
